function [checkerboard]=randCheckerboard(Colour1, Colour2, Colour2Tiles, M, N)      

% A function to create a square (5 by 5) checkerboard stimuli with tiles of
% up to two different colours. The tile positions are randomly
% distributed in the checkerboard each time the function is called but the 
% number of tiles of each colour are fixed. 

% Input: 
    % Colour1 = The first colour of the tiles. Input RGB values in [] format.
    % Colour2 = The second colour of the tiles. Input RGB values in [] format.
    % Colour2Tiles = Defines the number of tiles that will be drawn in the
    % colour specified in Colour2 input parameter. 
    % M = The pixel length on the x-axis. Needs to be dividable by 5.
    % N = The pixel length on the y-axis. Needs to be dividable by 5.

% Output:
    % checkerboard = (M+1)x(N+1)x3 array. 
%%
    % Set the number of tiles.  
    tileWidth=M/5; 
    tileHeight=N/5;
    
    % Create the checkerboard (matrix).
    checkerboard=zeros(M+1,N+1,3); 
    
    % Colour the whole checkerboard in the first colour. 
    checkerboard(:,:,1)=Colour1(1); 
    checkerboard(:,:,2)=Colour1(2);
    checkerboard(:,:,3)=Colour1(3);
    
    % Randomly select the position of the colour2 tiles.    
    Tiles=randperm(25,Colour2Tiles);
    
    % Colour the position of the colour2 tiles in their defined colour. 
    for TileNo=Tiles; 
        TileRow=ceil(TileNo/5); % Get the row position (1 to 5).
        TileColumn=(TileNo-(TileRow*5-4))+1; % Get the column position (1 to 5).
        checkerboard((TileRow-1)*tileWidth+1:TileRow*tileWidth,(TileColumn-1)*tileHeight+1:TileColumn*tileHeight,1)=Colour2(1);
        checkerboard((TileRow-1)*tileWidth+1:TileRow*tileWidth,(TileColumn-1)*tileHeight+1:TileColumn*tileHeight,2)=Colour2(2);
        checkerboard((TileRow-1)*tileWidth+1:TileRow*tileWidth,(TileColumn-1)*tileHeight+1:TileColumn*tileHeight,3)=Colour2(3);
    end
    
    % Draw 6 black horizontal lines to separate the tiles horizontally.   
    for pixel=1:tileWidth:M+1;
        checkerboard(pixel,:,:)=0;     
    end
    
    % Draw 6 black vertical lines to separate the tiles vertically.
    for pixel=1:tileHeight:N+1;
        checkerboard(:,pixel,:)=0;  
    end
 
end